import{s as zt,n as Wt,o as Bt}from"../chunks/scheduler.6062bdaf.js";import{S as Ut,i as Gt,g as a,s as o,r as d,A as jt,h as s,f as t,c as i,j as h,u,x as m,k as _,y as r,a as p,v as c,d as f,t as g,w as x}from"../chunks/index.4bca734e.js";import{D as b}from"../chunks/Docstring.ed07512f.js";import{H as ye}from"../chunks/Heading.723dceba.js";function Kt($t){let C,Oe,$e,Te,q,we,E,Ct="Exporting a model to ONNX involves specifying:",Ne,A,Ot=`<li>The input names.</li> <li>The output names.</li> <li>The dynamic axes. These refer to the input dimensions can be changed dynamically at runtime (e.g. a batch size or sequence length).
All other axes will be treated as static, and hence fixed at runtime.</li> <li>Dummy inputs to trace the model. This is needed in PyTorch to record the computational graph and convert it to ONNX.</li>`,De,I,Tt=`Since this data depends on the choice of model and task, we represent it in terms of <em>configuration classes</em>. Each configuration class is associated with
a specific model architecture, and follows the naming convention <code>ArchitectureNameOnnxConfig</code>. For instance, the configuration which specifies the ONNX
export of BERT models is <code>BertOnnxConfig</code>.`,Pe,V,wt="Since many architectures share similar properties for their ONNX configuration, 🤗 Optimum adopts a 3-level class hierarchy:",Le,F,Nt=`<li>Abstract and generic base classes. These handle all the fundamental features, while being agnostic to the modality (text, image, audio, etc).</li> <li>Middle-end classes. These are aware of the modality, but multiple can exist for the same modality depending on the inputs they support.
They specify which input generators should be used for the dummy inputs, but remain model-agnostic.</li> <li>Model-specific classes like the <code>BertOnnxConfig</code> mentioned above. These are the ones actually used to export models.</li>`,Se,H,ke,l,R,nt,ie,Dt="Base class for ONNX exportable model describing metadata on how to export the model through the ONNX format.",ot,re,Pt="Class attributes:",it,ae,Lt=`<li>NORMALIZED_CONFIG_CLASS (<code>Type</code>) — A class derived from <a href="/docs/optimum/main/en/utils/normalized_config#optimum.utils.NormalizedConfig">NormalizedConfig</a> specifying how to
normalize the model config.</li> <li>DUMMY_INPUT_GENERATOR_CLASSES (<code>Tuple[Type]</code>) — A tuple of classes derived from
<a href="/docs/optimum/main/en/utils/dummy_input_generators#optimum.utils.DummyInputGenerator">DummyInputGenerator</a> specifying how to create dummy inputs.</li> <li>ATOL_FOR_VALIDATION (<code>Union[float, Dict[str, float]]</code>) — A float or a dictionary mapping task names to float,
where the float values represent the absolute tolerance value to use during model conversion validation.</li> <li>DEFAULT_ONNX_OPSET (<code>int</code>, defaults to 11) — The default ONNX opset to use for the ONNX export.</li> <li>MIN_TORCH_VERSION (<code>packaging.version.Version</code>, defaults to <code>~optimum.exporters.onnx.utils.TORCH_MINIMUM_VERSION</code>) — The
minimum torch version supporting the export of the model to ONNX.</li> <li>MIN_TRANSFORMERS_VERSION (<code>packaging.version.Version</code>, defaults to
<code>~optimum.exporters.onnx.utils.TRANSFORMERS_MINIMUM_VERSION</code> — The minimum transformers version supporting the
export of the model to ONNX. Not always up-to-date or accurate. This is more for internal use.</li> <li>PATCHING_SPECS (<code>Optional[List[PatchingSpec]]</code>, defaults to <code>None</code>) — Specify which operators / modules should be
patched before performing the export, and how. This is useful when some operator is not supported in ONNX for
instance.</li>`,rt,P,X,at,se,St="Dict containing the axis definition of the input tensors to provide to the model.",st,L,z,pt,pe,kt="Dict containing the axis definition of the output tensors to provide to the model.",mt,S,W,lt,me,Mt="Generates the dummy inputs necessary for tracing the model. If not explicitely specified, default input shapes are used.",Me,y,B,dt,le,qt='Inherits from <a href="/docs/optimum/main/en/exporters/onnx/package_reference/configuration#optimum.exporters.onnx.OnnxConfig">OnnxConfig</a>. A base class to handle the ONNX configuration of decoder-only models.',ut,k,U,ct,de,Et="Fills <code>input_or_outputs</code> mapping with past_key_values dynamic axes considering the direction.",qe,$,G,ft,ue,At='Inherits from <a href="/docs/optimum/main/en/exporters/onnx/package_reference/configuration#optimum.exporters.onnx.OnnxConfigWithPast">OnnxConfigWithPast</a>. A base class to handle the ONNX configuration of encoder-decoder models.',gt,M,j,xt,ce,It="Creates a copy of the current OnnxConfig but with a different <code>ConfigBehavior</code> and <code>use_past</code> value.",Ee,K,Ae,Y,Ie,O,Z,ht,fe,Vt="Handles encoder-based text architectures.",Ve,T,J,_t,ge,Ft="Handles decoder-based text architectures.",Fe,w,Q,vt,xe,Ht="Handles encoder-decoder-based text architectures.",He,ee,Re,N,te,bt,he,Rt="Handles vision architectures.",Xe,ne,ze,D,oe,yt,_e,Xt="Handles multi-modal text and vision architectures.",We,Ce,Be;return q=new ye({props:{title:"Configuration classes for ONNX exports",local:"configuration-classes-for-onnx-exports",headingTag:"h1"}}),H=new ye({props:{title:"Base classes",local:"optimum.exporters.onnx.OnnxConfig",headingTag:"h2"}}),R=new b({props:{name:"class optimum.exporters.onnx.OnnxConfig",anchor:"optimum.exporters.onnx.OnnxConfig",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"},{name:"legacy",val:": bool = False"}],parametersDescription:[{anchor:"optimum.exporters.onnx.OnnxConfig.config",description:`<strong>config</strong> (<code>transformers.PretrainedConfig</code>) &#x2014;
The model configuration.`,name:"config"},{anchor:"optimum.exporters.onnx.OnnxConfig.task",description:`<strong>task</strong> (<code>str</code>, defaults to <code>&quot;feature-extraction&quot;</code>) &#x2014;
The task the model should be exported for.`,name:"task"},{anchor:"optimum.exporters.onnx.OnnxConfig.int_dtype",description:`<strong>int_dtype</strong> (<code>str</code>, defaults to <code>&quot;int64&quot;</code>) &#x2014;
The data type of integer tensors, could be [&#x201C;int64&#x201D;, &#x201C;int32&#x201D;, &#x201C;int8&#x201D;], default to &#x201C;int64&#x201D;.`,name:"int_dtype"},{anchor:"optimum.exporters.onnx.OnnxConfig.float_dtype",description:`<strong>float_dtype</strong> (<code>str</code>, defaults to <code>&quot;fp32&quot;</code>) &#x2014;
The data type of float tensors, could be [&#x201C;fp32&#x201D;, &#x201C;fp16&#x201D;, &#x201C;bf16&#x201D;], default to &#x201C;fp32&#x201D;.`,name:"float_dtype"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L102"}}),X=new b({props:{name:"inputs",anchor:"optimum.exporters.onnx.OnnxConfig.inputs",parameters:[],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L234",returnDescription:`<script context="module">export const metadata = 'undefined';<\/script>


<p>A mapping of each input name to a mapping of axis position to the axes symbolic name.</p>
`,returnType:`<script context="module">export const metadata = 'undefined';<\/script>


<p><code>Dict[str, Dict[int, str]]</code></p>
`}}),z=new b({props:{name:"outputs",anchor:"optimum.exporters.onnx.OnnxConfig.outputs",parameters:[],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L245",returnDescription:`<script context="module">export const metadata = 'undefined';<\/script>


<p>A mapping of each output name to a mapping of axis position to the axes symbolic name.</p>
`,returnType:`<script context="module">export const metadata = 'undefined';<\/script>


<p><code>Dict[str, Dict[int, str]]</code></p>
`}}),W=new b({props:{name:"generate_dummy_inputs",anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs",parameters:[{name:"framework",val:": str = 'pt'"},{name:"**kwargs",val:""}],parametersDescription:[{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.framework",description:`<strong>framework</strong> (<code>str</code>, defaults to <code>&quot;pt&quot;</code>) &#x2014;
The framework for which to create the dummy inputs.`,name:"framework"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.batch_size",description:`<strong>batch_size</strong> (<code>int</code>, defaults to 2) &#x2014;
The batch size to use in the dummy inputs.`,name:"batch_size"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.sequence_length",description:`<strong>sequence_length</strong> (<code>int</code>, defaults to 16) &#x2014;
The sequence length to use in the dummy inputs.`,name:"sequence_length"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.num_choices",description:`<strong>num_choices</strong> (<code>int</code>, defaults to 4) &#x2014;
The number of candidate answers provided for multiple choice task.`,name:"num_choices"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.image_width",description:`<strong>image_width</strong> (<code>int</code>, defaults to 64) &#x2014;
The width to use in the dummy inputs for vision tasks.`,name:"image_width"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.image_height",description:`<strong>image_height</strong> (<code>int</code>, defaults to 64) &#x2014;
The height to use in the dummy inputs for vision tasks.`,name:"image_height"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.num_channels",description:`<strong>num_channels</strong> (<code>int</code>, defaults to 3) &#x2014;
The number of channels to use in the dummpy inputs for vision tasks.`,name:"num_channels"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.feature_size",description:`<strong>feature_size</strong> (<code>int</code>, defaults to 80) &#x2014;
The number of features to use in the dummpy inputs for audio tasks in case it is not raw audio.
This is for example the number of STFT bins or MEL bins.`,name:"feature_size"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.nb_max_frames",description:`<strong>nb_max_frames</strong> (<code>int</code>, defaults to 3000) &#x2014;
The number of frames to use in the dummpy inputs for audio tasks in case the input is not raw audio.`,name:"nb_max_frames"},{anchor:"optimum.exporters.onnx.OnnxConfig.generate_dummy_inputs.audio_sequence_length",description:`<strong>audio_sequence_length</strong> (<code>int</code>, defaults to 16000) &#x2014;
The number of frames to use in the dummpy inputs for audio tasks in case the input is raw audio.`,name:"audio_sequence_length"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L456",returnDescription:`<script context="module">export const metadata = 'undefined';<\/script>


<p>A dictionary mapping the input names to dummy tensors in the proper framework format.</p>
`,returnType:`<script context="module">export const metadata = 'undefined';<\/script>


<p><code>Dict</code></p>
`}}),B=new b({props:{name:"class optimum.exporters.onnx.OnnxConfigWithPast",anchor:"optimum.exporters.onnx.OnnxConfigWithPast",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"},{name:"use_past",val:": bool = False"},{name:"use_past_in_inputs",val:": bool = False"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"legacy",val:": bool = False"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L557"}}),U=new b({props:{name:"add_past_key_values",anchor:"optimum.exporters.onnx.OnnxConfigWithPast.add_past_key_values",parameters:[{name:"inputs_or_outputs",val:": typing.Dict[str, typing.Dict[int, str]]"},{name:"direction",val:": str"}],parametersDescription:[{anchor:"optimum.exporters.onnx.OnnxConfigWithPast.add_past_key_values.inputs_or_outputs",description:`<strong>inputs_or_outputs</strong> (<code>Dict[str, Dict[int, str]]</code>) &#x2014;
The mapping to fill.`,name:"inputs_or_outputs"},{anchor:"optimum.exporters.onnx.OnnxConfigWithPast.add_past_key_values.direction",description:`<strong>direction</strong> (<code>str</code>) &#x2014;
either &#x201C;inputs&#x201D; or &#x201C;outputs&#x201D;, it specifies whether <code>input_or_outputs</code> is the input mapping or the
output mapping, this is important for axes naming.`,name:"direction"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L697"}}),G=new b({props:{name:"class optimum.exporters.onnx.OnnxSeq2SeqConfigWithPast",anchor:"optimum.exporters.onnx.OnnxSeq2SeqConfigWithPast",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"},{name:"use_past",val:": bool = False"},{name:"use_past_in_inputs",val:": bool = False"},{name:"behavior",val:": ConfigBehavior = <ConfigBehavior.MONOLITH: 'monolith'>"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"legacy",val:": bool = False"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L770"}}),j=new b({props:{name:"with_behavior",anchor:"optimum.exporters.onnx.OnnxSeq2SeqConfigWithPast.with_behavior",parameters:[{name:"behavior",val:": typing.Union[str, optimum.exporters.onnx.base.ConfigBehavior]"},{name:"use_past",val:": bool = False"},{name:"use_past_in_inputs",val:": bool = False"}],parametersDescription:[{anchor:"optimum.exporters.onnx.OnnxSeq2SeqConfigWithPast.with_behavior.behavior",description:`<strong>behavior</strong> (<code>ConfigBehavior</code>) &#x2014;
The behavior to use for the new instance.`,name:"behavior"},{anchor:"optimum.exporters.onnx.OnnxSeq2SeqConfigWithPast.with_behavior.use_past",description:`<strong>use_past</strong> (<code>bool</code>, defaults to <code>False</code>) &#x2014;
Whether or not the ONNX config to instantiate is for a model using KV cache.`,name:"use_past"},{anchor:"optimum.exporters.onnx.OnnxSeq2SeqConfigWithPast.with_behavior.use_past_in_inputs",description:`<strong>use_past_in_inputs</strong> (<code>bool</code>, defaults to <code>False</code>) &#x2014;
Whether the KV cache is to be passed as an input to the ONNX.`,name:"use_past_in_inputs"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/base.py#L805",returnType:`<script context="module">export const metadata = 'undefined';<\/script>


<p><code>OnnxSeq2SeqConfigWithPast</code></p>
`}}),K=new ye({props:{title:"Middle-end classes",local:"middle-end-classes",headingTag:"h2"}}),Y=new ye({props:{title:"Text",local:"optimum.exporters.onnx.TextEncoderOnnxConfig",headingTag:"h3"}}),Z=new b({props:{name:"class optimum.exporters.onnx.TextEncoderOnnxConfig",anchor:"optimum.exporters.onnx.TextEncoderOnnxConfig",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"},{name:"legacy",val:": bool = False"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/config.py#L55"}}),J=new b({props:{name:"class optimum.exporters.onnx.TextDecoderOnnxConfig",anchor:"optimum.exporters.onnx.TextDecoderOnnxConfig",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"},{name:"use_past",val:": bool = False"},{name:"use_past_in_inputs",val:": bool = False"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"legacy",val:": bool = False"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/config.py#L63"}}),Q=new b({props:{name:"class optimum.exporters.onnx.TextSeq2SeqOnnxConfig",anchor:"optimum.exporters.onnx.TextSeq2SeqOnnxConfig",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"},{name:"use_past",val:": bool = False"},{name:"use_past_in_inputs",val:": bool = False"},{name:"behavior",val:": ConfigBehavior = <ConfigBehavior.MONOLITH: 'monolith'>"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"legacy",val:": bool = False"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/config.py#L180"}}),ee=new ye({props:{title:"Vision",local:"optimum.exporters.onnx.config.VisionOnnxConfig",headingTag:"h3"}}),te=new b({props:{name:"class optimum.exporters.onnx.config.VisionOnnxConfig",anchor:"optimum.exporters.onnx.config.VisionOnnxConfig",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"},{name:"legacy",val:": bool = False"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/config.py#L247"}}),ne=new ye({props:{title:"Multi-modal",local:"optimum.exporters.onnx.config.TextAndVisionOnnxConfig",headingTag:"h3"}}),oe=new b({props:{name:"class optimum.exporters.onnx.config.TextAndVisionOnnxConfig",anchor:"optimum.exporters.onnx.config.TextAndVisionOnnxConfig",parameters:[{name:"config",val:": PretrainedConfig"},{name:"task",val:": str = 'feature-extraction'"},{name:"preprocessors",val:": typing.Optional[typing.List[typing.Any]] = None"},{name:"int_dtype",val:": str = 'int64'"},{name:"float_dtype",val:": str = 'fp32'"},{name:"legacy",val:": bool = False"}],source:"https://github.com/huggingface/optimum/blob/main/optimum/exporters/onnx/config.py#L255"}}),{c(){C=a("meta"),Oe=o(),$e=a("p"),Te=o(),d(q.$$.fragment),we=o(),E=a("p"),E.textContent=Ct,Ne=o(),A=a("ol"),A.innerHTML=Ot,De=o(),I=a("p"),I.innerHTML=Tt,Pe=o(),V=a("p"),V.textContent=wt,Le=o(),F=a("ol"),F.innerHTML=Nt,Se=o(),d(H.$$.fragment),ke=o(),l=a("div"),d(R.$$.fragment),nt=o(),ie=a("p"),ie.textContent=Dt,ot=o(),re=a("p"),re.textContent=Pt,it=o(),ae=a("ul"),ae.innerHTML=Lt,rt=o(),P=a("div"),d(X.$$.fragment),at=o(),se=a("p"),se.textContent=St,st=o(),L=a("div"),d(z.$$.fragment),pt=o(),pe=a("p"),pe.textContent=kt,mt=o(),S=a("div"),d(W.$$.fragment),lt=o(),me=a("p"),me.textContent=Mt,Me=o(),y=a("div"),d(B.$$.fragment),dt=o(),le=a("p"),le.innerHTML=qt,ut=o(),k=a("div"),d(U.$$.fragment),ct=o(),de=a("p"),de.innerHTML=Et,qe=o(),$=a("div"),d(G.$$.fragment),ft=o(),ue=a("p"),ue.innerHTML=At,gt=o(),M=a("div"),d(j.$$.fragment),xt=o(),ce=a("p"),ce.innerHTML=It,Ee=o(),d(K.$$.fragment),Ae=o(),d(Y.$$.fragment),Ie=o(),O=a("div"),d(Z.$$.fragment),ht=o(),fe=a("p"),fe.textContent=Vt,Ve=o(),T=a("div"),d(J.$$.fragment),_t=o(),ge=a("p"),ge.textContent=Ft,Fe=o(),w=a("div"),d(Q.$$.fragment),vt=o(),xe=a("p"),xe.textContent=Ht,He=o(),d(ee.$$.fragment),Re=o(),N=a("div"),d(te.$$.fragment),bt=o(),he=a("p"),he.textContent=Rt,Xe=o(),d(ne.$$.fragment),ze=o(),D=a("div"),d(oe.$$.fragment),yt=o(),_e=a("p"),_e.textContent=Xt,We=o(),Ce=a("p"),this.h()},l(e){const n=jt("svelte-u9bgzb",document.head);C=s(n,"META",{name:!0,content:!0}),n.forEach(t),Oe=i(e),$e=s(e,"P",{}),h($e).forEach(t),Te=i(e),u(q.$$.fragment,e),we=i(e),E=s(e,"P",{"data-svelte-h":!0}),m(E)!=="svelte-dlt5nt"&&(E.textContent=Ct),Ne=i(e),A=s(e,"OL",{"data-svelte-h":!0}),m(A)!=="svelte-8uy4wn"&&(A.innerHTML=Ot),De=i(e),I=s(e,"P",{"data-svelte-h":!0}),m(I)!=="svelte-dj35tg"&&(I.innerHTML=Tt),Pe=i(e),V=s(e,"P",{"data-svelte-h":!0}),m(V)!=="svelte-1xr1iy9"&&(V.textContent=wt),Le=i(e),F=s(e,"OL",{"data-svelte-h":!0}),m(F)!=="svelte-172xxrj"&&(F.innerHTML=Nt),Se=i(e),u(H.$$.fragment,e),ke=i(e),l=s(e,"DIV",{class:!0});var v=h(l);u(R.$$.fragment,v),nt=i(v),ie=s(v,"P",{"data-svelte-h":!0}),m(ie)!=="svelte-1gqzpaz"&&(ie.textContent=Dt),ot=i(v),re=s(v,"P",{"data-svelte-h":!0}),m(re)!=="svelte-wz8va1"&&(re.textContent=Pt),it=i(v),ae=s(v,"UL",{"data-svelte-h":!0}),m(ae)!=="svelte-1043q6c"&&(ae.innerHTML=Lt),rt=i(v),P=s(v,"DIV",{class:!0});var Ue=h(P);u(X.$$.fragment,Ue),at=i(Ue),se=s(Ue,"P",{"data-svelte-h":!0}),m(se)!=="svelte-41mopq"&&(se.textContent=St),Ue.forEach(t),st=i(v),L=s(v,"DIV",{class:!0});var Ge=h(L);u(z.$$.fragment,Ge),pt=i(Ge),pe=s(Ge,"P",{"data-svelte-h":!0}),m(pe)!=="svelte-ayslnd"&&(pe.textContent=kt),Ge.forEach(t),mt=i(v),S=s(v,"DIV",{class:!0});var je=h(S);u(W.$$.fragment,je),lt=i(je),me=s(je,"P",{"data-svelte-h":!0}),m(me)!=="svelte-jhf9pw"&&(me.textContent=Mt),je.forEach(t),v.forEach(t),Me=i(e),y=s(e,"DIV",{class:!0});var ve=h(y);u(B.$$.fragment,ve),dt=i(ve),le=s(ve,"P",{"data-svelte-h":!0}),m(le)!=="svelte-1bekc5k"&&(le.innerHTML=qt),ut=i(ve),k=s(ve,"DIV",{class:!0});var Ke=h(k);u(U.$$.fragment,Ke),ct=i(Ke),de=s(Ke,"P",{"data-svelte-h":!0}),m(de)!=="svelte-1vefvm0"&&(de.innerHTML=Et),Ke.forEach(t),ve.forEach(t),qe=i(e),$=s(e,"DIV",{class:!0});var be=h($);u(G.$$.fragment,be),ft=i(be),ue=s(be,"P",{"data-svelte-h":!0}),m(ue)!=="svelte-1o424ha"&&(ue.innerHTML=At),gt=i(be),M=s(be,"DIV",{class:!0});var Ye=h(M);u(j.$$.fragment,Ye),xt=i(Ye),ce=s(Ye,"P",{"data-svelte-h":!0}),m(ce)!=="svelte-1mrnpw0"&&(ce.innerHTML=It),Ye.forEach(t),be.forEach(t),Ee=i(e),u(K.$$.fragment,e),Ae=i(e),u(Y.$$.fragment,e),Ie=i(e),O=s(e,"DIV",{class:!0});var Ze=h(O);u(Z.$$.fragment,Ze),ht=i(Ze),fe=s(Ze,"P",{"data-svelte-h":!0}),m(fe)!=="svelte-sreje6"&&(fe.textContent=Vt),Ze.forEach(t),Ve=i(e),T=s(e,"DIV",{class:!0});var Je=h(T);u(J.$$.fragment,Je),_t=i(Je),ge=s(Je,"P",{"data-svelte-h":!0}),m(ge)!=="svelte-1fe0pgy"&&(ge.textContent=Ft),Je.forEach(t),Fe=i(e),w=s(e,"DIV",{class:!0});var Qe=h(w);u(Q.$$.fragment,Qe),vt=i(Qe),xe=s(Qe,"P",{"data-svelte-h":!0}),m(xe)!=="svelte-1yn8wb"&&(xe.textContent=Ht),Qe.forEach(t),He=i(e),u(ee.$$.fragment,e),Re=i(e),N=s(e,"DIV",{class:!0});var et=h(N);u(te.$$.fragment,et),bt=i(et),he=s(et,"P",{"data-svelte-h":!0}),m(he)!=="svelte-10ord85"&&(he.textContent=Rt),et.forEach(t),Xe=i(e),u(ne.$$.fragment,e),ze=i(e),D=s(e,"DIV",{class:!0});var tt=h(D);u(oe.$$.fragment,tt),yt=i(tt),_e=s(tt,"P",{"data-svelte-h":!0}),m(_e)!=="svelte-1fm9mpu"&&(_e.textContent=Xt),tt.forEach(t),We=i(e),Ce=s(e,"P",{}),h(Ce).forEach(t),this.h()},h(){_(C,"name","hf:doc:metadata"),_(C,"content",Yt),_(P,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),_(L,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),_(S,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),_(l,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),_(k,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),_(y,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),_(M,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),_($,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),_(O,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),_(T,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),_(w,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),_(N,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),_(D,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8")},m(e,n){r(document.head,C),p(e,Oe,n),p(e,$e,n),p(e,Te,n),c(q,e,n),p(e,we,n),p(e,E,n),p(e,Ne,n),p(e,A,n),p(e,De,n),p(e,I,n),p(e,Pe,n),p(e,V,n),p(e,Le,n),p(e,F,n),p(e,Se,n),c(H,e,n),p(e,ke,n),p(e,l,n),c(R,l,null),r(l,nt),r(l,ie),r(l,ot),r(l,re),r(l,it),r(l,ae),r(l,rt),r(l,P),c(X,P,null),r(P,at),r(P,se),r(l,st),r(l,L),c(z,L,null),r(L,pt),r(L,pe),r(l,mt),r(l,S),c(W,S,null),r(S,lt),r(S,me),p(e,Me,n),p(e,y,n),c(B,y,null),r(y,dt),r(y,le),r(y,ut),r(y,k),c(U,k,null),r(k,ct),r(k,de),p(e,qe,n),p(e,$,n),c(G,$,null),r($,ft),r($,ue),r($,gt),r($,M),c(j,M,null),r(M,xt),r(M,ce),p(e,Ee,n),c(K,e,n),p(e,Ae,n),c(Y,e,n),p(e,Ie,n),p(e,O,n),c(Z,O,null),r(O,ht),r(O,fe),p(e,Ve,n),p(e,T,n),c(J,T,null),r(T,_t),r(T,ge),p(e,Fe,n),p(e,w,n),c(Q,w,null),r(w,vt),r(w,xe),p(e,He,n),c(ee,e,n),p(e,Re,n),p(e,N,n),c(te,N,null),r(N,bt),r(N,he),p(e,Xe,n),c(ne,e,n),p(e,ze,n),p(e,D,n),c(oe,D,null),r(D,yt),r(D,_e),p(e,We,n),p(e,Ce,n),Be=!0},p:Wt,i(e){Be||(f(q.$$.fragment,e),f(H.$$.fragment,e),f(R.$$.fragment,e),f(X.$$.fragment,e),f(z.$$.fragment,e),f(W.$$.fragment,e),f(B.$$.fragment,e),f(U.$$.fragment,e),f(G.$$.fragment,e),f(j.$$.fragment,e),f(K.$$.fragment,e),f(Y.$$.fragment,e),f(Z.$$.fragment,e),f(J.$$.fragment,e),f(Q.$$.fragment,e),f(ee.$$.fragment,e),f(te.$$.fragment,e),f(ne.$$.fragment,e),f(oe.$$.fragment,e),Be=!0)},o(e){g(q.$$.fragment,e),g(H.$$.fragment,e),g(R.$$.fragment,e),g(X.$$.fragment,e),g(z.$$.fragment,e),g(W.$$.fragment,e),g(B.$$.fragment,e),g(U.$$.fragment,e),g(G.$$.fragment,e),g(j.$$.fragment,e),g(K.$$.fragment,e),g(Y.$$.fragment,e),g(Z.$$.fragment,e),g(J.$$.fragment,e),g(Q.$$.fragment,e),g(ee.$$.fragment,e),g(te.$$.fragment,e),g(ne.$$.fragment,e),g(oe.$$.fragment,e),Be=!1},d(e){e&&(t(Oe),t($e),t(Te),t(we),t(E),t(Ne),t(A),t(De),t(I),t(Pe),t(V),t(Le),t(F),t(Se),t(ke),t(l),t(Me),t(y),t(qe),t($),t(Ee),t(Ae),t(Ie),t(O),t(Ve),t(T),t(Fe),t(w),t(He),t(Re),t(N),t(Xe),t(ze),t(D),t(We),t(Ce)),t(C),x(q,e),x(H,e),x(R),x(X),x(z),x(W),x(B),x(U),x(G),x(j),x(K,e),x(Y,e),x(Z),x(J),x(Q),x(ee,e),x(te),x(ne,e),x(oe)}}}const Yt='{"title":"Configuration classes for ONNX exports","local":"configuration-classes-for-onnx-exports","sections":[{"title":"Base classes","local":"optimum.exporters.onnx.OnnxConfig","sections":[],"depth":2},{"title":"Middle-end classes","local":"middle-end-classes","sections":[{"title":"Text","local":"optimum.exporters.onnx.TextEncoderOnnxConfig","sections":[],"depth":3},{"title":"Vision","local":"optimum.exporters.onnx.config.VisionOnnxConfig","sections":[],"depth":3},{"title":"Multi-modal","local":"optimum.exporters.onnx.config.TextAndVisionOnnxConfig","sections":[],"depth":3}],"depth":2}],"depth":1}';function Zt($t){return Bt(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class nn extends Ut{constructor(C){super(),Gt(this,C,Zt,Kt,zt,{})}}export{nn as component};
